#!/bin/bash
#*****************************************************************
# File:   pract4_correcta.bash
# Author: PSCD-Universidad de Zaragoza
# Date:   octubre 2019
# Coms:   script de comprobacin de entrega de la prctica 4 de PSCD (19/20)
#         Funcionamiento: 
#          1) Dar permisos de ejecucin al script: "chmod u+x pract4_correcta.bash"
#          2) Ejecutar mediante "pract4_correcta.bash miNip" en el directorio donde est el zip
#             a entregar, en este caso "practica4_miNip.zip". Crear un directorio temporal
#             donde descomprimir el zip, comprobar si estn los ficheros que tienen que estar
#             y si se compilan correctamente, informando de los problemas.
#             Posteriormente borra el directorio creado
#*****************************************************************

DIR_CORRECCION=$(pwd)
MAKE_FILE=Makefile_p4
EJECUTABLE=main_p4
FUENTE_ZIP="practica4_${1}.zip"
USER=a$1       #usuarios en Hendrix son "a" seguido del NIP
FALTAN=()      #ficheros que faltan
FICHEROS=(AlquilerBicicletas/PuntoAlquiler.cpp \
	      AlquilerBicicletas/PuntoAlquiler.hpp \
	      AlquilerBicicletas/${EJECUTABLE}.cpp \
	      informe_p4.pdf)
DIRECTORIOS=(AlquilerBicicletas librerias/Logger_V2)

#si alguien usa esto como nombre de directorio, se merece el castigo de perderlo
DIR_TEMPORAL=${DIR_CORRECCION}/__PSCD_NO_ES_INTERESANTE__
DIR_COMPILACION=${DIR_TEMPORAL}/AlquilerBicicletas

FORM=" ------> "

echo "------------------------------------------"
#----------------------------------------------------------------
#Comprueba que se invoque con un parmetro (que se supone es un NIP)
if [[ "$#" -ne 1 ]]
then
	echo "Invocar como: pract4_correcta.bash miNip"
	echo "------------------------------------------"
	exit
fi
#----------------------------------------------------------------
#  crear directorio temporal. Si existe, lo borra. Si alguien
#  haba llamado a un directorio as, se lo merece
echo "${FORM}Creando directorio temporal ..."
if [ -d "${DIR_TEMPORAL}" ]
then
	/bin/rm -rf ${DIR_TEMPORAL}
fi
mkdir ${DIR_TEMPORAL}
#----------------------------------------------------------------
#  mirar si ha entregado el fichero "zip"

if [ ! -f "${FUENTE_ZIP}" ]
then
	FALTAN=( ${FUENTE_ZIP} "${FALTAN}[@]")
	echo "${FORM}Falta fichero ${FUENTE_ZIP}"
else #comprobar estn todos los directorios requeridos
	cp ${FUENTE_ZIP} ${DIR_TEMPORAL}/${FUENTE_ZIP}
	cd ${DIR_TEMPORAL}
	echo "${FORM}Extrayendo zip ..."
	unzip ${FUENTE_ZIP}
	for dir in "${DIRECTORIOS[@]}"
	do
		if [ ! -d "$dir" ]
		then
			echo "${FORM}Falta directorio ${dir}"
			FALTAN=(${dir} "${FALTAN}[@]")
		fi
	done
fi
#comprobar estn todos los ficheros requeridos
if [[ ${#FALTAN[@]} -eq 0 ]] 
then
	for fich in "${FICHEROS[@]}"
	do
		if [ ! -f "$fich" ]
		then
			echo "${FORM}Falta fichero ${fich}"
			FALTAN=(${fich} "${FALTAN}[@]")
		fi
	done
fi

#Si faltan directorios o ficheros, no se compila
if [[ ${#FALTAN[@]} -eq 0 ]] 
then
	cd ${DIR_COMPILACION}
	make -f ${MAKE_FILE}
	resMake=$?
	if [[ "${resMake}" == 0 ]]
	then    #ha funcionado bien
		echo "${FORM}Compila correctamente"
	else
		echo "${FORM}ERROR: fallo al compilar"
	fi
else
	echo "${FORM}ERROR: faltan ficheros obligatorios"
fi

#volver al directorio original
cd ${DIR_CORRECCION}
#borrar el temporal
echo "${FORM}Borrando directorio temporal ..."
/bin/rm -rf ${DIR_TEMPORAL}*
echo "------------------------------------------"
stty erase "^?"
exit 0
